Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7864)

Unified Diff: chrome/browser/browsing_data_remover.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/policy/policy_templates.json ('k') | chrome/browser/browsing_data_remover.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browsing_data_remover.h
diff --git a/chrome/browser/browsing_data_remover.h b/chrome/browser/browsing_data_remover.h
index d47462438a5b2aef81ca9317256120db569ab557..c34db65ade7be003da2d66a253fe71e4e1292e1c 100644
--- a/chrome/browser/browsing_data_remover.h
+++ b/chrome/browser/browsing_data_remover.h
@@ -72,14 +72,14 @@ class BrowsingDataRemover : public content::NotificationObserver,
REMOVE_PLUGIN_DATA = 1 << 9,
REMOVE_PASSWORDS = 1 << 10,
REMOVE_WEBSQL = 1 << 11,
- REMOVE_ORIGIN_BOUND_CERTS = 1 << 12,
+ REMOVE_SERVER_BOUND_CERTS = 1 << 12,
// "Site data" includes cookies, appcache, file systems, indexedDBs, local
// storage, webSQL, and plugin data.
REMOVE_SITE_DATA = REMOVE_APPCACHE | REMOVE_COOKIES | REMOVE_FILE_SYSTEMS |
REMOVE_INDEXEDDB | REMOVE_LOCAL_STORAGE |
REMOVE_PLUGIN_DATA | REMOVE_WEBSQL |
- REMOVE_ORIGIN_BOUND_CERTS
+ REMOVE_SERVER_BOUND_CERTS
};
// When BrowsingDataRemover successfully removes data, a notification of type
@@ -235,13 +235,13 @@ class BrowsingDataRemover : public content::NotificationObserver,
// Invoked on the IO thread to delete cookies.
void ClearCookiesOnIOThread(net::URLRequestContextGetter* rq_context);
- // Invoked on the IO thread to delete origin bound certs.
- void ClearOriginBoundCertsOnIOThread(
+ // Invoked on the IO thread to delete server bound certs.
+ void ClearServerBoundCertsOnIOThread(
net::URLRequestContextGetter* rq_context);
// Callback when origin bound certs have been deleted. Invokes
// NotifyAndDeleteIfDone.
- void OnClearedOriginBoundCerts();
+ void OnClearedServerBoundCerts();
// Calculate the begin time for the deletion range specified by |time_period|.
base::Time CalculateBeginDeleteTime(TimePeriod time_period);
@@ -252,7 +252,7 @@ class BrowsingDataRemover : public content::NotificationObserver,
!waiting_for_clear_cookies_count_&&
!waiting_for_clear_history_ &&
!waiting_for_clear_networking_history_ &&
- !waiting_for_clear_origin_bound_certs_ &&
+ !waiting_for_clear_server_bound_certs_ &&
!waiting_for_clear_plugin_data_ &&
!waiting_for_clear_quota_managed_data_;
}
@@ -300,7 +300,7 @@ class BrowsingDataRemover : public content::NotificationObserver,
int waiting_for_clear_cookies_count_;
bool waiting_for_clear_history_;
bool waiting_for_clear_networking_history_;
- bool waiting_for_clear_origin_bound_certs_;
+ bool waiting_for_clear_server_bound_certs_;
bool waiting_for_clear_plugin_data_;
bool waiting_for_clear_quota_managed_data_;
« no previous file with comments | « chrome/app/policy/policy_templates.json ('k') | chrome/browser/browsing_data_remover.cc » ('j') | no next file with comments »
@@ -235,13 +235,13 @@ class BrowsingDataRemover : public content::NotificationObserver,
net::URLRequestContextGetter* rq_context);
- // Callback when origin bound certs have been deleted. Invokes
+ // Callback when server bound certs have been deleted. Invokes
// NotifyAndDeleteIfDone.

Powered by Google App Engine
This is Rietveld 408576698